# Generated by roxygen2: do not edit by hand

export(BinomialAUC)
export(BinomialModel)
export(CIBERSORT)
export(CalculatePref)
export(CalculateTimeROC)
export(Construct_con)
export(ConvertRownameToLoci)
export(CoreAlg)
export(DrawQQPlot)
export(EPIC)
export(Enet)
export(GetFractions.Abbas)
export(GetOutlierGenes)
export(IPS_calculation)
export(LR_cal)
export(MCPcounter.estimate)
export(ParseInputExpression)
export(PlotAUC)
export(PlotTimeROC)
export(ProcessingData)
export(PrognosticAUC)
export(PrognosticModel)
export(PrognosticResult)
export(RegressionResult)
export(RemoveBatchEffect)
export(SplitTrainTest)
export(Top_probe)
export(add_iobr_mirror)
export(add_riskscore)
export(anno_eset)
export(assimilate_data)
export(batch_cor)
export(batch_kruskal)
export(batch_pcc)
export(batch_sig_surv_plot)
export(batch_surv)
export(batch_wilcoxon)
export(best_cutoff)
export(best_cutoff2)
export(calculate_break_month)
export(calculate_sig_score)
export(calculate_sig_score_integration)
export(calculate_sig_score_pca)
export(calculate_sig_score_ssgsea)
export(calculate_sig_score_zscore)
export(cell_bar_plot)
export(check_cancer_types)
export(check_eset)
export(clear_iobr_cache)
export(combine_pd_eset)
export(count2tpm)
export(creat_folder)
export(deconvo_cibersort)
export(deconvo_epic)
export(deconvo_estimate)
export(deconvo_ips)
export(deconvo_mcpcounter)
export(deconvo_quantiseq)
export(deconvo_ref)
export(deconvo_timer)
export(deconvo_tme)
export(deconvo_xcell)
export(deconvolute_quantiseq.default)
export(deconvolute_timer.default)
export(design_mytheme)
export(doPerm)
export(download_iobr_data)
export(enrichment_barplot)
export(eset_distribution)
export(estimateScore)
export(exact_pvalue)
export(extract_sc_data)
export(feature_manipulation)
export(feature_select)
export(filterCommonGenes)
export(find_markers_in_bulk)
export(find_mutations)
export(find_outlier_samples)
export(find_variable_genes)
export(format_msigdb)
export(format_signatures)
export(generateRef)
export(generateRef_DEseq2)
export(generateRef_limma)
export(generateRef_rnaseq)
export(generateRef_seurat)
export(getHRandCIfromCoxph)
export(get_cols)
export(get_cor)
export(get_cor_matrix)
export(get_iobr_cache_dir)
export(get_sig_sc)
export(high_var_fea)
export(iobr_cor_plot)
export(iobr_deconvo_pipeline)
export(iobr_deg)
export(iobr_pca)
export(ipsmap)
export(lasso_select)
export(limma.dif)
export(list_github_datasets)
export(list_iobr_mirrors)
export(load_data)
export(log2eset)
export(make_mut_matrix)
export(mapbw)
export(mapcolors)
export(merge_duplicate)
export(merge_eset)
export(mouse2human_eset)
export(outputGCT)
export(output_sig)
export(palettes)
export(parallel_doperm)
export(patterns_to_na)
export(percent_bar_plot)
export(pie_chart)
export(plotPurity)
export(random_strata_cells)
export(rbind_iobr)
export(remove_batcheffect)
export(remove_duplicate_genes)
export(remove_names)
export(reset_iobr_cache_dir)
export(reset_iobr_mirrors)
export(roc_time)
export(scale_matrix)
export(select_method)
export(set_iobr_cache_dir)
export(sigScore)
export(sig_box)
export(sig_box_batch)
export(sig_forest)
export(sig_gsea)
export(sig_heatmap)
export(sig_pheatmap)
export(sig_roc)
export(sig_surv_plot)
export(signature_score_calculation_methods)
export(subgroup_survival)
export(surv_group)
export(tcga_rna_preps)
export(test_for_infiltration)
export(timer_available_cancers)
export(timer_info)
export(tme_cluster)
export(tme_deconvolution_methods)
export(transform_data)
import(dplyr)
import(ggplot2)
import(glmnet)
import(grid)
import(parallel)
import(purrr)
import(stringr)
import(survival)
import(tibble)
import(tidyr)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,curve)
importFrom(graphics,legend)
importFrom(graphics,matlines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,stars)
importFrom(methods,as)
importFrom(methods,is)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,dist)
importFrom(stats,end)
importFrom(stats,glm)
importFrom(stats,hclust)
importFrom(stats,kruskal.test)
importFrom(stats,lm)
importFrom(stats,lsfit)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.exclude)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,prcomp)
importFrom(stats,pt)
importFrom(stats,qqplot)
importFrom(stats,quantile)
importFrom(stats,reorder)
importFrom(stats,sd)
importFrom(stats,start)
importFrom(stats,time)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(survminer,surv_cutpoint)
importFrom(tibble,column_to_rownames)
importFrom(utils,adist)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,menu)
importFrom(utils,packageDescription)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,read.table)
importFrom(utils,tail)
importFrom(utils,write.csv)
importFrom(utils,write.table)
