# R/imports.R
#' @importFrom grDevices colorRampPalette dev.off pdf png rgb
#' @importFrom graphics abline barplot box curve legend matlines mtext par points stars
#' @importFrom methods as is
#' @importFrom stats aggregate as.formula binomial coef complete.cases cor cor.test dist end glm hclust kruskal.test lm lsfit mad median model.matrix na.exclude na.omit p.adjust pchisq pnorm prcomp pt qqplot quantile reorder sd start time var wilcox.test
#' @importFrom utils adist combn data head menu packageVersion read.csv read.delim read.table tail write.csv write.table
NULL
