% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/deconvo_tme.R
\name{deconvo_ips}
\alias{deconvo_ips}
\title{Calculate Immunophenoscore (IPS)}
\usage{
deconvo_ips(eset, project = NULL, plot = FALSE)
}
\arguments{
\item{eset}{Gene expression matrix.}

\item{project}{Optional project name. Default is `NULL`.}

\item{plot}{Logical: generate visualization. Default is `FALSE`.}
}
\value{
Data frame with IPS scores. Columns suffixed with `_IPS`.
}
\description{
Calculates immune phenotype scores from gene expression data.
}
\examples{
\dontrun{
ips_genes <- load_data("ips_gene_set")
if (!is.null(ips_genes)) {
  set.seed(123)
  sim_eset <- matrix(rnorm(nrow(ips_genes) * 2), nrow(ips_genes), 2)
  rownames(sim_eset) <- ips_genes$GENE
  colnames(sim_eset) <- paste0("Sample", 1:2)
  result <- deconvo_ips(eset = sim_eset, project = "Example")
  if (!is.null(result)) head(result)
}
}
}
\author{
Dongqiang Zeng
}
