% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download_data.R
\name{add_iobr_mirror}
\alias{add_iobr_mirror}
\title{Add Custom Download Mirror}
\usage{
add_iobr_mirror(url, position = c("first", "last", "before_github"))
}
\arguments{
\item{url}{Character string. The mirror URL to add.}

\item{position}{Character. Where to add the mirror: "first", "last", or
"before_github". Default: "first".}
}
\value{
Invisibly returns the updated mirror list.
}
\description{
Adds a custom mirror URL to the default mirrors for the current session.
The mirror URL should be a base URL. If it contains 'github.com', it will
be treated as a GitHub proxy and the relative path to IOBR releases will
be appended. Otherwise, it will be treated as a direct repository path.
}
\examples{
\dontrun{
add_iobr_mirror("https://my-mirror.com/https://github.com")
}
}
