% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/deconvo_tme.R
\name{deconvo_epic}
\alias{deconvo_epic}
\title{Deconvolve Immune Microenvironment Using EPIC}
\usage{
deconvo_epic(eset, project = NULL, tumor = TRUE)
}
\arguments{
\item{eset}{Gene expression matrix with genes as row names.}

\item{project}{Optional project name. Default is `NULL`.}

\item{tumor}{Logical indicating tumor (`TRUE`) or normal (`FALSE`) samples.}
}
\value{
Data frame with EPIC cell fraction estimates. Columns suffixed with
  `_EPIC`.
}
\description{
Estimates immune cell fractions using EPIC algorithm.
}
\examples{
\dontrun{
TRef <- load_data("TRef")
if (!is.null(TRef)) {
  set.seed(123)
  sim_eset <- matrix(rnorm(nrow(TRef$refProfiles) * 2), nrow(TRef$refProfiles), 2)
  rownames(sim_eset) <- rownames(TRef$refProfiles)
  colnames(sim_eset) <- paste0("Sample", 1:2)
  result <- deconvo_epic(eset = sim_eset, project = "Example", tumor = TRUE)
  if (!is.null(result)) head(result)
}
}
}
\author{
Dongqiang Zeng
}
