% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generateRef_DEseq2.R
\name{Top_probe}
\alias{Top_probe}
\title{Top Probe Selector}
\usage{
Top_probe(dat, i)
}
\arguments{
\item{dat}{Data frame containing a column named "probe".}

\item{i}{Integer. Number of top probes to return.}
}
\value{
Character vector containing the names of the top `i` probes.
}
\description{
Extracts the top `i` probes based on their ordering in the provided data
frame. If the number of rows is less than or equal to `i`, returns all
probes.
}
\examples{
dat <- data.frame(
  probe = c("Probe1", "Probe2", "Probe3", "Probe4", "Probe5"),
  value = c(5, 3, 2, 4, 1)
)
top_probes <- Top_probe(dat, 3)
print(top_probes)
}
