% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_sig_sc.R
\name{get_sig_sc}
\alias{get_sig_sc}
\title{Extract Top Marker Genes from Single-Cell Differential Results}
\usage{
get_sig_sc(
  deg,
  cluster = "cluster",
  gene = "gene",
  avg_log2FC = "avg_log2FC",
  n = 100
)
}
\arguments{
\item{deg}{Data frame or matrix. Ranked marker statistics.}

\item{cluster}{Character. Column name containing cluster identifiers.
Default is `"cluster"`.}

\item{gene}{Character. Column name containing gene identifiers.
Default is `"gene"`.}

\item{avg_log2FC}{Character. Column name for average log2 fold change.
Default is `"avg_log2FC"`.}

\item{n}{Integer. Number of top markers per cluster. Default is 100.}
}
\value{
List of character vectors; each element contains the top N genes
  for a cluster.
}
\description{
Selects the top N marker genes per cluster from a ranked differential
expression result table.
}
\examples{
# Simulate marker data
set.seed(123)
sim_deg <- data.frame(
  cluster = rep(c("A", "B"), each = 50),
  gene = paste0("Gene", 1:100),
  avg_log2FC = rnorm(100, 2, 1)
)

# Extract top 5 markers per cluster
markers <- get_sig_sc(sim_deg, n = 5)
print(markers)
}
