% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generateRef_rnaseq.R
\name{generateRef_rnaseq}
\alias{generateRef_rnaseq}
\title{Generate Reference Gene Matrix from RNA-seq DEGs}
\usage{
generateRef_rnaseq(dds, pheno, mode = "oneVSothers", FDR = 0.05, dat)
}
\arguments{
\item{dds}{Matrix. Raw count data from RNA-seq.}

\item{pheno}{Character vector. Cell type classes.}

\item{mode}{Character. DEG identification mode: `"oneVSothers"` or
`"pairs"`. Default is `"oneVSothers"`.}

\item{FDR}{Numeric. Threshold for adjusted p-values. Default is 0.05.}

\item{dat}{Matrix. Normalized expression data (e.g., FPKM, TPM).}
}
\value{
List containing:
  - `reference_matrix`: Data frame of median expression for significant
    genes across cell types.
  - `G`: Optimal number of probes minimizing condition number.
  - `condition_number`: Minimum condition number.
  - `whole_matrix`: Full median expression matrix.
}
\description{
Uses DESeq2 to identify differentially expressed genes and create a
reference matrix from median expression levels across cell types.
}
\examples{
dds <- matrix(rpois(200 * 10, lambda = 10), ncol = 10)
rownames(dds) <- paste("Gene", 1:200, sep = "_")
colnames(dds) <- paste("Sample", 1:10, sep = "_")
pheno <- sample(c("Type1", "Type2", "Type3"), 10, replace = TRUE)
dat <- matrix(rnorm(200 * 10), ncol = 10)
rownames(dat) <- rownames(dds)
colnames(dat) <- colnames(dds)
\donttest{
results <- generateRef_rnaseq(dds = dds, pheno = pheno, FDR = 0.05, dat = dat)
}
}
\author{
Rongfang Shen
}
