% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcpcounter.R
\name{test_for_infiltration}
\alias{test_for_infiltration}
\title{Test for Cell Population Infiltration}
\usage{
test_for_infiltration(MCPcounterMatrix, platform = c("133P2", "133A", "HG1"))
}
\arguments{
\item{MCPcounterMatrix}{Matrix, usually output from MCPcounter.estimate.}

\item{platform}{Expression platform: "133P2", "133A", or "HG1".
Default is "133P2".}
}
\value{
Matrix with samples in rows and cell populations in columns.
  Elements are p-values.
}
\description{
Returns p-values for the null hypothesis that samples are not infiltrated
by the corresponding cell population.
}
\examples{
# This function requires null_models data which is loaded internally
# Create example data
scores <- matrix(runif(30), nrow = 3, ncol = 10)
rownames(scores) <- c("T cells", "B cells", "NK cells")
pvals <- test_for_infiltration(scores, platform = "133P2")
}
\author{
Etienne Becht
}
