% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download_data.R
\name{get_iobr_cache_dir}
\alias{get_iobr_cache_dir}
\title{Get IOBR Cache Directory}
\usage{
get_iobr_cache_dir(cache_dir = NULL)
}
\arguments{
\item{cache_dir}{Optional character string to override the current setting.}
}
\value{
Character string with the cache directory path.
}
\description{
Returns the current cache directory for IOBR downloaded data.
To comply with CRAN policies, the default cache directory is a session-specific
temporary directory. Users can opt-in to a persistent cache by setting
`options(IOBR.cache_dir = "your/path")` or using `set_iobr_cache_dir()`.

The cache directory is determined in the following priority order:
1. Function argument `cache_dir` (if provided)
2. Option `IOBR.cache_dir` (if set via `options()`)
3. Default: A session-specific temporary directory (`file.path(tempdir(), "IOBR_cache")`)
}
\examples{
# Get current cache directory (defaults to tempdir)
get_iobr_cache_dir()

# Set custom cache directory via options (use tempdir() for examples)
options(IOBR.cache_dir = tempdir())
get_iobr_cache_dir()
}
