% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/timer.R
\name{ParseInputExpression}
\alias{ParseInputExpression}
\title{Parse Input Gene Expression Data}
\usage{
ParseInputExpression(path)
}
\arguments{
\item{path}{Character. Path to a tab-delimited gene expression file.
First column should contain gene identifiers.}
}
\value{
Numeric matrix of gene expression values with genes as rows and
  samples as columns.
}
\description{
Reads gene expression data from a tab-delimited text file, using the first
column as row names. Converts data into a numeric matrix for analysis.
}
\examples{
tf <- tempfile(fileext = ".tsv")
expr <- data.frame(
  gene = c("GeneA", "GeneB", "GeneC"),
  Sample1 = c(10, 20, 30),
  Sample2 = c(15, 25, 35)
)
write.table(expr, tf, sep = "\t", row.names = FALSE, quote = FALSE)
gene_expression_data <- ParseInputExpression(tf)
print(gene_expression_data)
}
